import React, { useState, useEffect } from 'react';
import {
  GridComponent,
  ColumnDirective,
  ColumnsDirective,
  Page,
  Inject,
  Edit,
  EditSettingsModel,
  Toolbar,
  ToolbarItems,
  dataStateChange,
} from '@syncfusion/ej2-react-grids';
import { getOrders, addOrder, updateOrder, deleteOrder } from './orderService';
import './App.css';

const App: React.FC = () => {
  const editOptions: EditSettingsModel = { allowEditing: true, allowAdding: true, allowDeleting: true };
  const toolbarOptions: ToolbarItems[] = ['Add', 'Edit', 'Delete', 'Update', 'Cancel'];

  const [data, setData] = useState();
  useEffect(() => {
    refreshGrid();
  }, []);

  function refreshGrid() {
    getOrders()
      .then(
        data => {
          setData(data);
        }
      );
  }
  function dataStateChange(args: any){
    refreshGrid();
  }

  function dataSourceChanged(state: any) {
    if (state.action === "add") {
      console.log(state);
      addOrder(state.data)
        .then(res => state.endEdit());
    } else if (state.action === "edit") {
      updateOrder(state.data)
      .then(res => state.endEdit());
    } else if (state.requestType === "delete") {
      deleteOrder(state.data[0].OrderID)
      .then(res => state.endEdit());
    }
  }
  return (
    <div style={{ margin: '10%', marginTop: '5%' }}>
      <GridComponent dataSource={data}
        allowPaging={true}
        editSettings={editOptions}
        toolbar={toolbarOptions}
        dataSourceChanged={dataSourceChanged}
        dataStateChange = {dataStateChange}
      >
        <ColumnsDirective>
          <ColumnDirective field='OrderID' headerText='Invoice ID' textAlign='Right' width='100' isPrimaryKey={true} />
          <ColumnDirective field='CustomerID' headerText='Customer ID' width='150' />
          <ColumnDirective field='ShipCountry' headerText='Ship Country' />
          <ColumnDirective field='ShipName' headerText='Ship Name' />
          <ColumnDirective field='Freight' textAlign='Right' format='C2' width='150' />
          <ColumnDirective field='OrderDate' headerText='OrderDate' type='date' format='yMd' width='150' />
        </ColumnsDirective>
        <Inject services={[Page, Edit, Toolbar]} />
      </GridComponent>
    </div>
  );
}

export default App;